@@ -26,7 +26,7 @@ from torch import cuda
 
 import json
 
-from utils.coords_calc import add_grid, convert_yolo_to_coords, convert_coco_to_coords, crop_from_coords
+from cnn_runner.utils.coords_calc import add_grid, convert_yolo_to_coords, convert_coco_to_coords, crop_from_coords
 
 qApp.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
 
@@ -1319,7 +1319,7 @@ class ObjectDetectionWindow(QMainWindow):
         event.accept()  # Закрываем окно
 
 
-if __name__ == '__main__':
+def run():
     import sys
     from PyQt5.QtWidgets import QApplication
     from qt_material import apply_stylesheet
